@@ -226,7 +226,7 @@ bool MTStroke::writeSequence()
   QString strokefilename;
   strokefilename = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1String("/kmousetool_strokes.txt" );
 
-  ofstream outfile (strokefilename.toLatin1(), ios::out);
+  ofstream outfile (strokefilename.toLatin1().constData(), ios::out);
   if (!outfile) {
     return false;
   }
